Document title goes here

# Sectors

Please choose a geographical region of which you would like to view or copy a survey.

### Pan European

- European Commission provided examples

### Countries

- Austria
- Belgium
- Bulgaria
- Cyprus
- The Czech Republic
- Germany
- Denmark
- Estonia
- Spain
- Finland
- France
- The United Kingdom
- Greece
- Hungary
- Ireland
- Italy
- Lithuania
- Luxembourg
- Latvia
- Malta
- The Netherlands
- Poland
- Portugal
- Romania
- Sweden
- Slovenia
- Slovakia

- Surveys
- Documentation
- Sectors
- OiRA
- Search

### Survey versions

Survey 2010

- Current / Published January 4 2009 Preview Edit

Survey 2009

- Current December 12 2009 Preview Edit
- Published August 5 2009 Preview Edit Update
- March 18 2009 Preview Edit
- February 2 2009 Preview Edit
- January 28 2009 Preview Edit

##### Legend

- Current Version that is currently online
- Current Version you are currently reviewing

Update = This version has changes that are currently unpublished. Click the update icon to bring all the changes live

Draft

Leave retracted Published
Write a revision note.
Notify

Link to sector organisation | Disclaimer | Design by Cornae